@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,7 @@
 #include "seahorse-gpgmex.h"
 #include "seahorse-passphrase.h"
 
-#ifdef WITH_GNOME_KEYRING
 #include <gnome-keyring.h>
-#endif
 
 #ifndef DEBUG_OPERATION_ENABLE
 #if _DEBUG
@@ -941,8 +939,6 @@ seahorse_ssh_operation_generate (SeahorseSSHSource *src, const gchar *email,
  * LOAD KEY INTO AGENT
  */ 
 
-#ifdef WITH_GNOME_KEYRING
-
 #define KEYRING_ATTR_TYPE "seahorse-key-type"
 #define KEYRING_ATTR_KEYID "openssh-keyid"
 #define KEYRING_VAL_SSH "openssh"
@@ -994,8 +990,10 @@ set_keyring_passphrase (SeahorseKey *skey, const gchar *pass)
     const gchar *id;
     gchar *display;
     
-    g_assert (id != NULL);
+    g_assert ((skey != NULL) && (pass != NULL));
+    
     id = seahorse_key_get_rawid (seahorse_key_get_keyid (skey));
+    g_assert (id != NULL);
     display = seahorse_key_get_display_name (skey);
     
     attributes = gnome_keyring_attribute_list_new ();
@@ -1010,12 +1008,9 @@ set_keyring_passphrase (SeahorseKey *skey, const gchar *pass)
         g_warning ("Couldn't store password in keyring: (code %d)", res);
 }
 
-#endif /* WITH_GNOME_KEYRING */
-
 static const gchar*
 load_password_cb (SeahorseSSHOperation *sop, const gchar* msg)
 {
-#ifdef WITH_GNOME_KEYRING
     SeahorseSSHOperationPrivate *pv = SEAHORSE_SSH_OPERATION_GET_PRIVATE (sop);
     gchar* pass;
 
@@ -1029,7 +1024,6 @@ load_password_cb (SeahorseSSHOperation *sop, const gchar* msg)
         }
         pv->prompt_requests++;
     }
-#endif /* WITH_GNOME_KEYRING */
     
     return prompt_passphrase (sop, _("Secure Shell Key Passphrase"), _("Enter the passphrase for: %s"), 
                               _("Save this passphrase in my keyring"), FALSE);
@@ -1038,7 +1032,6 @@ load_password_cb (SeahorseSSHOperation *sop, const gchar* msg)
 static void
 load_result_cb (SeahorseSSHOperation *sop)
 {
-#ifdef WITH_GNOME_KEYRING
     SeahorseSSHOperationPrivate *pv = SEAHORSE_SSH_OPERATION_GET_PRIVATE (sop);
     const gchar* pass;
     
@@ -1046,27 +1039,6 @@ load_result_cb (SeahorseSSHOperation *sop)
         pass = seahorse_passphrase_prompt_get (pv->prompt_dialog);
         set_keyring_passphrase (pv->prompt_skey, pass);
     }
-#endif /* WITH_GNOME_KEYRING */
-}
-
-SeahorseOperation*
-seahorse_ssh_operation_agent_load (SeahorseSSHSource *src, SeahorseSSHKey *skey)
-{
-    SeahorseSSHOperationPrivate *pv;
-    SeahorseOperation *op;
-    gchar *cmd;
-    
-    g_return_val_if_fail (skey->keydata->privfile, NULL);
-    
-    cmd = g_strdup_printf (SSH_ADD_PATH " '%s'", skey->keydata->privfile);
-    op = seahorse_ssh_operation_new (src, cmd, NULL, 0, skey);
-    g_free (cmd);
-    
-    pv = SEAHORSE_SSH_OPERATION_GET_PRIVATE (op);
-    pv->result_cb = load_result_cb;
-    pv->password_cb = load_password_cb;
-    
-    return op;
 }
 
 /* -----------------------------------------------------------------------------
